        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,12,15,17,18,21,25,27,28,29,30,33,34,36,37,38,39,42,44,48';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <br>1,3,4,7,8,9,10,13,14,16,19,22,31,35,40,45,46,47,49,50';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 11 <br>2,5,6,11,20,23,24,26,32,41,43';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,12,15,17,18,21,25,27,28,29,30,33,34,36,37,38,39,42,44,48';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <br>1,3,4,7,8,9,10,13,14,16,19,22,31,35,40,45,46,47,49,50';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 11 <br>2,5,6,11,20,23,24,26,32,41,43';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,12,15,17,18,21,25,27,28,29,30,33,34,36,37,38,39,42,44,48';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <br>1,3,4,7,8,9,10,13,14,16,19,22,31,35,40,45,46,47,49,50';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 11 <br>2,5,6,11,20,23,24,26,32,41,43';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,12,15,17,18,21,25,27,28,29,30,33,34,36,37,38,39,42,44,48';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <br>1,3,4,7,8,9,10,13,14,16,19,22,31,35,40,45,46,47,49,50';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 11 <br>2,5,6,11,20,23,24,26,32,41,43';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,12,15,17,18,21,25,27,28,29,30,33,34,36,37,38,39,42,44,48';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <br>1,3,4,7,8,9,10,13,14,16,19,22,31,35,40,45,46,47,49,50';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 11 <br>2,5,6,11,20,23,24,26,32,41,43';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>39</strong> miembros: 20 <strong>control</strong><br>0,12,15,17,18,21,25,27,28,29,30,33,34,36,37,38,39,42,44,48';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 20 <br>1,3,4,7,8,9,10,13,14,16,19,22,31,35,40,45,46,47,49,50';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260717 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>26</strong> miembros: 11 <br>2,5,6,11,20,23,24,26,32,41,43';}
}
